/**
* @license Apache-2.0
*
* Copyright (c) 2023 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

// MODULES //

var factory = require( './factory.js' );


// MAIN //

/**
* Returns pseudorandom numbers drawn from an exponential distribution with rate parameter `lambda`.
*
* @name exponential
* @type {Function}
* @param {NonNegativeIntegerArray} shape - array shape
* @param {(PositiveNumber|ndarrayLike)} lambda - rate parameter
* @param {Options} [options] - options
* @param {string} [options.dtype="float64"] - array data type
* @param {string} [options.order="row-major"] - memory layout (either row-major or column-major)
* @param {string} [options.mode="throw"] - specifies how to handle indices which exceed array dimensions
* @param {StringArray} [options.submode=["throw"]] - specifies how to handle subscripts which exceed array dimensions on a per dimension basis
* @param {boolean} [options.readonly=false] - boolean indicating whether an array should be read-only
* @throws {TypeError} first argument must be a valid shape
* @throws {TypeError} must provide valid distribution parameters
* @throws {TypeError} distribution parameters and the desired shape must be broadcast compatible
* @throws {TypeError} options argument must be an object
* @throws {TypeError} must provide valid options
* @returns {ndarray} output array
*
* @example
* var arr = exponential( [ 10 ], 2.0 );
* // returns <ndarray>
*
* @example
* var arr = exponential( [ 10 ], 2.0, {
*     'dtype': 'generic'
* });
* // returns <ndarray>
*/
var exponential = factory();


// EXPORTS //

module.exports = exponential;
